# Readme
A tool for automatically generating presigned download URLs for AWS S3 using boto3

## Install
+ Follow the aws-cli install proceedure [found here](https://docs.aws.amazon.com/cli/latest/userguide/installing.html)
+ Make sure you have configured your aws cli account credentials
+ Run `pip install presign`

## Usage
+ Run `presign --help` for a breakdown of command line arguments